@@ -55,8 +55,8 @@ KXE_TreeView::KXE_TreeView( KXMLGUIClient * pGUIClient, TQWidget * pParent, cons
 
 	setSelectionMode(TQListView::Single);
 
-	connect( this, SIGNAL(selectionChanged()), this, SLOT(slotSelectionChanged()) );
-	connect( this, SIGNAL(expanded(TQListViewItem*)), this, SLOT(slotItemExpanded(TQListViewItem*)) );
+	connect( this, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(slotSelectionChanged()) );
+	connect( this, TQ_SIGNAL(expanded(TQListViewItem*)), this, TQ_SLOT(slotItemExpanded(TQListViewItem*)) );
 
 	setReadWrite(false);
 
@@ -65,12 +65,12 @@ KXE_TreeView::KXE_TreeView( KXMLGUIClient * pGUIClient, TQWidget * pParent, cons
   m_pDropItem = 0;
 
 	m_autoOpenTimer = new TQTimer(this);
-  connect(m_autoOpenTimer, SIGNAL(timeout()), this, SLOT(slotAutoOpenFolder()));
+  connect(m_autoOpenTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotAutoOpenFolder()));
 
 	// Apply current configuration
 	slotTreeViewSettingsChanged();
 	// and make sure to be informed about its changes.
-	connect( KXMLEditorFactory::configuration()->treeview(), SIGNAL(sigChanged()), this, SLOT(slotTreeViewSettingsChanged()) );
+	connect( KXMLEditorFactory::configuration()->treeview(), TQ_SIGNAL(sigChanged()), this, TQ_SLOT(slotTreeViewSettingsChanged()) );
 }
 
 void KXE_TreeView::setReadWrite( bool fReadWrite )
